#!/bin/bash
# This is a script to build a Zenwalk package. Check the Zenwalk homepage: www.zenwalk.org
#
# SOFTWARE			: libxmi
# PROJECT HOMEPAGE 	: http://www.gnu.org/software/libxmi
# SOURCES          	: ftp://ftp.gnu.org/gnu/libxmi
#
# MAINTAINER       	: skywatcher (s.skywatcher|AT|gmail|DOT|org, simone antoniucci)
# LATEST REVISION	: 2009-04-19
#
# BUILD-ONLY DEPS	: -
# NOTES				: -

### Checking for unbound variables
set -u

### Setting main variables
NAME="libxmi"
VERSION="1.2"
ARCH="i486"
CPU="i686"
BUILD=62.1

HOMEPAGE="http://www.gnu.org/software/libxmi"
DESCRIPTION="Library for rasterizing 2-D vector graphics"
SRCLNK="ftp://ftp.gnu.org/gnu/libxmi/$NAME-$VERSION.tar.gz"

CWD=`pwd`
PKGDIR=$CWD/$NAME-install
PKG=$NAME-$VERSION-$ARCH-$BUILD
SRCPKG=`echo $SRCLNK | rev | cut -d/ -f1 | rev`
SRCDIR=$CWD/$NAME-$VERSION

URL=http://zenwalk.pinguix.com/user-accounts/skywatcher/$NAME/$VERSION
DOCS="AUTHORS CUSTOMIZE ChangeLog COPYING INSTALL NEWS README* TODO VERSION"

NJOBS="-j2"
export CFLAGS="-O2 -march=$ARCH -mtune=$CPU"
export CXXFLAGS="-O2 -march=$ARCH -mtune=$CPU"

### Cleaning
rm -rf $PKGDIR
rm -rf $SRCDIR

### Mkdir
mkdir -p $PKGDIR
mkdir -p $PKGDIR/install
mkdir -p $PKGDIR/usr/doc/$NAME-$VERSION
mkdir -p $PKGDIR/usr/src/$NAME-$VERSION
#~ mkdir -p $PKGDIR/usr/share/applications
#~ mkdir -p $ICONDIR

### Checking if source is present. If it's not, download it
if [ -f $SRCPKG ]; then
	echo "Source file is already present, no need to download it";
else
 	echo "Downloading source..."
	wget -c -nv $SRCLNK
fi

### Extracting source
tar xfv $SRCPKG

### Configure, make, install
cd $SRCDIR
./configure --prefix=/usr --sysconfdir=/etc --localstatedir=/var --mandir=/usr/man --disable-static || exit 1
make $NJOBS || exit 1
make install DESTDIR=$PKGDIR || exit 1

### Stripping binaries
cd $PKGDIR
find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null

### Docs, man, info
cd $SRCDIR
cp -a $DOCS $PKGDIR/usr/doc/$NAME-$VERSION
find $PKGDIR/usr/man -type f -exec gzip -9 {} \;
find $PKGDIR/usr/info -type f -exec gzip -9 {} \;

### Adding build-file and other stuff to the package
cp -a $CWD/$0 $PKGDIR/usr/src/$NAME-$VERSION/build-$NAME.sh
chmod a+x $PKGDIR/usr/src/$NAME-$VERSION/build-$NAME.sh

### Slack-desc 
#    |-----handy-ruler------------------------------------------------------|
cat > $PKGDIR/install/slack-desc << EOF
$NAME: $NAME - $DESCRIPTION
$NAME:  
$NAME: GNU libxmi is a C/C++ function library for rasterizing 2-D vector 
$NAME: graphics. It can draw 2-D graphical primitives, including wide 
$NAME: polygonal lines and circular and elliptical arcs, into a 
$NAME: user-supplied matrix of pixels. Sophisticated line styles, such as
$NAME: multicolored dashing patterns, can be specified. There is also 
$NAME: support for filling and texturing polygons.
$NAME: 
$NAME: 
$NAME: $HOMEPAGE
EOF

### Ownerships and permissions
cd $PKGDIR
chown -R root:root .
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

### Unneeded stuff
rm -fr $PKGDIR/usr/info/dir.gz

### doinst
cat > $PKGDIR/install/doinst.sh << EOF
if [ -x usr/bin/install-info ]
then
   usr/bin/install-info --info-dir=usr/info usr/info/enfuse.info.gz 2>/dev/null
   usr/bin/install-info --info-dir=usr/info usr/info/enblend.info.gz 2>/dev/null
   usr/bin/install-info --info-dir=usr/info usr/info/enfuse-focus-stacking.info.gz 2>/dev/null
fi
EOF

### Making the package
makepkg -l y -c n $CWD/$PKG.tgz

### md5
cd $CWD
md5sum $PKG.tgz > $PKG.md5

### dep
#~ depfinder $PKG.tgz > $PKG.dep
echo "glibc" >  $PKG.dep

### txt
cat $PKGDIR/install/slack-desc > $PKG.txt

### src
rm -fr $PKG.src
for link in $URL/$0 $SRCLNK 
	do echo $link >> $PKG.src
done

### Cleaning
rm -rf $SRCDIR
rm -rf $PKGDIR

### Done. Ciao!
